Module values

Module values 

Structs

InternalId
Internal ID for nodes and relationships in the graph database.

Enums

GraphValue
A value returned from a Cypher query, encoded per the Strana protocol spec.
TaggedValue
Graph-specific types that use a $type discriminator.

Functions

from_lbug_value
Convert a LadybugDB Value into a Strana GraphValue.
json_params_to_lbug
Convert a JSON params object to a Vec of (name, lbug::Value) pairs.
to_lbug_value
Convert a JSON value to a LadybugDB value for parameter binding.