Structs
Functions
- apply_
retention - Apply Grandfather-Father-Son retention to snapshots and compact the journal.
- create_
snapshot - Create a point-in-time snapshot of the database.
- download_
snapshot_ s3 - Download a snapshot tarball from S3 and extract it to
dest_dir. - find_
latest_ snapshot_ s3 - Find the latest snapshot key in the bucket with the given prefix.
- restore
- Restore the database from a snapshot, then replay journal entries.
- upload_
snapshot_ s3 - Tar + zstd-compress a snapshot directory and upload it to S3.